import Component from 'libs/Component'
import DOMElement from 'libs/DOMElement'

export function updateSelectValues(el: HTMLInputElement, values: Array<string | number | { title: string | number, description?: string | number | null, value?: string | number, image?: string }>, options?: { clearText?: boolean } = { clearText: false }) {
	const list = new DOMElement(el.parentElement?.querySelector('ul')!)
	const label = el.parentElement?.parentElement!
	label.dataset.component = 'select'
	const name = el.dataset.name!

	const displayValue = el.value
	if (options.clearText && !values.includes(displayValue)) {
		el.value = ''
	}

	list.removeChilds()

	for (let item of values) {
		if (typeof item !== 'object') {
			item = { title: item }
		}

		list.appendChild(
			new DOMElement('li')
				.addClass('flex')
				.appendChild(
					new DOMElement('label')
						.addClass('flex', 'gap-2')
						.appendChild(
							new DOMElement('input')
								.attr('width', 14)
								.attr('height', 14)
								.attr('hidden', !el.dataset.multiple)
								.attr('type', el.dataset.multiple ? 'checkbox' : 'radio')
								.attr('name', name)
								.attr('value', item.value ?? item.title)
								.attr('checked', ''),
							new DOMElement('div')
								.classList('flex', 'gap-2', 'items-center')
								.appendChild(
									item.image ? new DOMElement('img')
										.attr('width', 24)
										.attr('height', 24)
										.classList('rounded-full', 'w-6', 'h-6')
										.attr('src', item.image) : undefined,
									new DOMElement('div')
										.appendChild(
											new DOMElement('p')
												.text(item.title.toString())
										)
								)
						)
				)
		)
	}

	Component.load(label)

}
