# Libs

Globally independent objects/classes/functions that SHOULD be unit testable by themselve

## Hyperion

Hyperion is a library that allows you to make change to the HTML content dynamically depending on the results of a JSON request

it is kinda a mix of React/Svelte and HTMX

it use both `data-` items and `<template />` elements

example:

```html
<!-- define your input -->
<button
	data-action="/api/v1/checkout" // the endpoint to use
	data-template="#pouet" // the template to use
>Checkout</button>

<!-- Define the template to fill -->
<template id="pouet"><p
	data-attribute="test" // the JSON path
></p></template>
```

### Attributes

**on Item Attributes**

| nom           | default   | Type    | Valeurs possible                | Description                                              |
| ------------- | --------- | ------- | ------------------------------- | -------------------------------------------------------- |
| data-trigger  | click     | Texte   | Standard Event, load, after:xxx | see Triggers                                             |
| data-action   |           | Texte   |                                 | the url to fetch                                         |
| data-method   | GET       | Texte   | GET, POST, PUT, DELETE          | the method to use                                        |
| data-path     |           | Texte   |                                 | the subpath to start from in the template                |
| data-target   | innerHTML | Texte   | innerHTML, outerHTML            | the target element, see Target                           |
| data-template |           | Texte   | CSS Query                       | the template CSS query                                   |
| data-multiple |           | Boolean |                                 | if set, it will run on an array, else on everything else |

**In template Attributes**

| nom            | default | Type | Valeurs possible | Description                                  |
| -------------- | ------- | ---- | ---------------- | -------------------------------------------- |
| data-attribute |         | Text |                  | the attribute to get from the fetched object |
| data-type      | text    | Text |                  | text, html, outerHTML, outerText             |

### Triggers

To make a trigger you can define a WebStandard HTML Event like `click`, `mouseover`, etc and it will work after it is emitted by the browser.

there is also a special `load` trigger that will run hyperion on the tag after the page has loaded

you can have multiple triggers by adding them all with a space between (ex: `data-trigger="click, blur"`)

there is also modifiers:
- `once`: the request will run only once and never again after (note: `load` trigger don't count for this)
- `after:x`: Dedupplicate the request sent to the server by waiting at least `x` millis with not triggering done


### Targets

Targets defin where the generated content will be placed.

- `innerHTML`: it will be placed as a child of the current element
- `outerHTML`: it will replace the current element at the same position (making it runnable once)

You can also as a second argument change le location of the target by usin a CSS query

example:
```html
<button
	...
	data-target="innerHTML #pouet"
>Button</button>

<p id="pouet"></p>
```

Finally you can run the query from the current element you can prepend the query by `this`
example:
```html
<div
	...
	data-target="innerHTML this.pouet"
>
	<p class="pouet"></p>
</div>
```
