import { defineMiddleware } from 'astro/middleware'
import { buildRFC7807 } from 'libs/RFCs/RFC7807'
import config from 'models/config'
import route from 'route'

// `context` and `next` are automatically typed
export default defineMiddleware(async (ctx, next) => {
	const url = ctx.url
	const client = config.mainClient
	const c = await client.get()
	await c.connect()
	const isMigrated = await c.isMigrated()

	if (!isMigrated) {
		c.migrateToLatest()
	}
	// check if the client is ready
	if (!isMigrated && url.pathname !== '/setup') {
		if (url.pathname.startsWith('/api')) {
			// don't redirect but indicate it usign a RFC7807
			return buildRFC7807({
				title: 'Server is starting up',
				status: 503,
				details: 'Server is starting, please wait a bit'
			})
		}
		// redirect user to a specific page
		return ctx.redirect(route('/setup', { goto: url.pathname + url.search }))
	}

	if (isMigrated && url.pathname === '/setup') {
		return ctx.redirect(url.searchParams.get('goto') ?? route('/'))
	}
	return next()
})
