import Schema, { s, type SchemaInfer } from 'libs/Schema'
import Priority from 'models/Priority'

const schema = new Schema({
	/**
	 * the project ID
	 */
	id: s.string().attr('db:unique', 'db:auto'),
	localid: s.number(),
	project: s.string(),

	/**
	 * the email the project was created from
	 */
	name: s.string().nullable(),

	description: s.string().nullable(),

	state: s.string(), //state id
	priority: s.number().defaultValue(Priority.NONE),
	begin: s.nullable(s.date()),
	due: s.nullable(s.date()),

	/**
	 * Parent issue
	 */
	parent: s.string().nullable(),

	/**
	 * issue labels
	 */
	labels: s.array(s.string()),

	/**
	 * is the issue archived
	 */
	archived: s.boolean().defaultValue(false)
})

export default schema

export type ProjectObj = SchemaInfer<typeof schema>
