import type { ClientStatic } from './Clients'
import PostgresClient from './Clients/PostgresClient'
import Dao from './Dao'
import Project from './Project'

import PostgresAdapter from './Adapters/PostgresAdapter'
import History from './History'
import Issue from './Issue'
import type Migration from './Migrations/Migration'
import Migration0 from './Migrations/Migration0'
import Migration20240515T95748 from './Migrations/Migration2024-05-15T9-57-48'
import State from './State'

// @ts-ignore
interface Config {
	mainClient: ClientStatic
	models: Record<string, Dao>
	migrations: Array<Migration>

}

const config = {
	mainClient: PostgresClient as ClientStatic<PostgresClient>,
	migrations: ([
		Migration0,
		Migration20240515T95748,
		{
			date: Date.UTC(2024, 10, 4),
			async up(client) {
				await client.execute(`CREATE TABLE IF NOT EXISTS history (
					id TEXT PRIMARY KEY,
					description TEXT,
					issue TEXT,
					"user" TEXT,
					created DATE
				)`)
			}
		}
	] as Array<Migration>).sort((a, b) => a.date - b.date),
	models: {
		project: new Dao(Project, new PostgresAdapter(Project, 'project')),
		issue: new Dao(Issue, new PostgresAdapter(Issue, 'issue')),
		state: new Dao(State, new PostgresAdapter(State, 'state')),
		history: new Dao(History, new PostgresAdapter(History, 'history'))

	}
} as const

export default config
