import { objectMap, objectOmit } from '@dzeio/object-util'
import type { APIRoute } from 'astro'
import ResponseBuilder from 'libs/ResponseBuilder'
import DaoFactory from 'models/DaoFactory'

export const GET: APIRoute = async (ctx) => {
	const projectId = ctx.params.id!
	const taskId = ctx.params.issueId!
	const dao = DaoFactory.get('issue')

	return new ResponseBuilder()
		.body((await dao.findOne({ project: projectId, id: taskId })))
		.build()
}
export const POST: APIRoute = async (ctx) => {
	const history = DaoFactory.get('history')
	const taskId = ctx.params.issueId!
	const dao = DaoFactory.get('issue')
	const body = objectOmit(await ctx.request.json(), 'label')
	const req = await dao.get(taskId)
	const res = await dao.patch(taskId, { id: taskId, ...body })
	await history.create({
		user: '',
		description: objectMap(body, (value, key) => {
			if (req![key as 'id'] === value) {
				return null
			}
			return `${String(key)} changed to ${value}`
		}).filter((it) => !!it).join('\n'),
		issue: taskId
	})

	return new ResponseBuilder()
		.body(res)
		.build()
}
