import type { APIRoute } from 'astro'
import ResponseBuilder from 'libs/ResponseBuilder'
import DaoFactory from 'models/DaoFactory'
import Priority, { getPriorityText } from 'models/Priority'
import { Sort } from 'models/Query'

export const POST: APIRoute = async (ctx) => {
	const projectId = ctx.params.id!
	const dao = DaoFactory.get('issue')
	const stateDao = DaoFactory.get('state')
	let { rows: issueCount } = await dao.findAll({
		project: projectId
	})
	const defaultState = await stateDao.findOne({
		project: projectId,
		preset: true
	})
	const json = await ctx.request.json()

	const isMultiple = json.multiple
	delete json.multiple

	let tasks: Array<string> = [json.name]
	if (isMultiple) {
		tasks = json.name.split('\n')
	}
	delete json.name

	const res: Array<any> = []

	for (const task of tasks) {
		res.push(await dao.create({
			...json,
			name: task,
			project: projectId,
			localid: issueCount++,
			state: defaultState?.id ?? 'empty',
			labels: []
		}))
	}

	return new ResponseBuilder().body(res).build()
}

export const GET: APIRoute = async (ctx) => {
	const projectId = ctx.params.id!
	const sort = ctx.params.sort ?? 'localid'
	const dao = DaoFactory.get('issue')
	const stateDao = DaoFactory.get('state')
	const states = (await stateDao.findAll({ project: projectId })).data
	const issues = (await dao.findAll({ project: projectId, $sort: { [sort]: Sort.ASC } })).data

	const res = issues.map((it) => ({
		...it,
		state: states.find((st) => st.id === it.state),
		priority: getPriorityText(it.priority ?? Priority.NONE)
	}))

	return new ResponseBuilder()
		.body(res)
		.build()
}
